@@ -1,6 +1,6 @@
 #! /bin/bash
 
-VERSION=0.15.8
+VERSION=0.16.4
 
 make dist
 mkdir -p ../deb/
@@ -10,6 +10,8 @@ cp -v stimfit-${VERSION}.tar.gz ../deb/stimfit_${VERSION}.orig.tar.gz
 cd ../deb/
 tar -xzf stimfit_${VERSION}.orig.tar.gz
 cd stimfit-${VERSION}
-cp -rv ../../../dist/debian ./
-debuild -S -sa
-sudo pbuilder build --basetgz /var/cache/pbuilder/base.tgz ../*.dsc
+cp -rv ../../stimfit/dist/debian ./
+# debuild -S -sa
+debuild -i -us -uc -S
+debuild -i -us -uc -b
+# sudo pbuilder build --basetgz /var/cache/pbuilder/base.tgz ../*.dsc
